@@ -51,8 +51,11 @@ showTreeCall <- function(e, w) {
     w$write("(")
     walkCode(e[[1]], w)
     for (a in as.list(e[-1])) {
-        w$write(" ");
-        walkCode(a, w);
+        w$write(" ")
+        if (missing(a))
+            w$write("<Missing>")
+        else
+            walkCode(a, w)
     }
     w$write(")")
 }
@@ -703,7 +706,7 @@ addCollectUsageHandler("if", "base", function(e, w) {
     if (is.logical(test) && length(test) == 1 && ! is.na(test)) {
         walkCode(e[[2]], w)
         if (test) walkCode(e[[3]], w)
-        else walkCode(e[[4]], w)
+        else if (length(e) > 3) walkCode(e[[4]], w)
     }
     else collectUsageArgs(e, w)
 })
